@@ -16,12 +16,12 @@
  *
  * Returns length of MAC including key ID and digest.
  */
-int
+size_t
 MD5authencrypt(
-	int	type,		/* hash algorithm */
-	u_char	*key,		/* key pointer */
-	u_int32 *pkt,		/* packet pointer */
-	int	length		/* packet length */
+	int		type,	/* hash algorithm */
+	const u_char *	key,	/* key pointer */
+	u_int32 *	pkt,	/* packet pointer */
+	size_t		length	/* packet length */
 	)
 {
 	u_char	digest[EVP_MAX_MD_SIZE];
@@ -34,13 +34,17 @@ MD5authencrypt(
 	 * was creaded.
 	 */
 	INIT_SSL();
+#if defined(OPENSSL) && OPENSSL_VERSION_NUMBER >= 0x0090700fL
 	if (!EVP_DigestInit(&ctx, EVP_get_digestbynid(type))) {
 		msyslog(LOG_ERR,
 		    "MAC encrypt: digest init failed");
 		return (0);
 	}
+#else
+	EVP_DigestInit(&ctx, EVP_get_digestbynid(type));
+#endif
 	EVP_DigestUpdate(&ctx, key, cache_secretsize);
-	EVP_DigestUpdate(&ctx, (u_char *)pkt, (u_int)length);
+	EVP_DigestUpdate(&ctx, (u_char *)pkt, length);
 	EVP_DigestFinal(&ctx, digest, &len);
 	memmove((u_char *)pkt + length + 4, digest, len);
 	return (len + 4);
@@ -54,11 +58,11 @@ MD5authencrypt(
  */
 int
 MD5authdecrypt(
-	int	type,		/* hash algorithm */
-	u_char	*key,		/* key pointer */
-	u_int32	*pkt,		/* packet pointer */
-	int	length,	 	/* packet length */
-	int	size		/* MAC size */
+	int		type,	/* hash algorithm */
+	const u_char *	key,	/* key pointer */
+	u_int32	*	pkt,	/* packet pointer */
+	size_t		length,	/* packet length */
+	size_t		size	/* MAC size */
 	)
 {
 	u_char	digest[EVP_MAX_MD_SIZE];
@@ -71,20 +75,24 @@ MD5authdecrypt(
 	 * was created.
 	 */
 	INIT_SSL();
+#if defined(OPENSSL) && OPENSSL_VERSION_NUMBER >= 0x0090700fL
 	if (!EVP_DigestInit(&ctx, EVP_get_digestbynid(type))) {
 		msyslog(LOG_ERR,
 		    "MAC decrypt: digest init failed");
 		return (0);
 	}
+#else
+	EVP_DigestInit(&ctx, EVP_get_digestbynid(type));
+#endif
 	EVP_DigestUpdate(&ctx, key, cache_secretsize);
-	EVP_DigestUpdate(&ctx, (u_char *)pkt, (u_int)length);
+	EVP_DigestUpdate(&ctx, (u_char *)pkt, length);
 	EVP_DigestFinal(&ctx, digest, &len);
-	if ((u_int)size != len + 4) {
+	if (size != (size_t)len + 4) {
 		msyslog(LOG_ERR,
 		    "MAC decrypt: MAC length error");
 		return (0);
 	}
-	return !memcmp(digest, (char *)pkt + length + 4, len);
+	return !memcmp(digest, (const char *)pkt + length + 4, len);
 }
 
 /*
@@ -105,6 +113,8 @@ addr2refid(sockaddr_u *addr)
 		return (NSRCADR(addr));
 
 	INIT_SSL();
+
+#if defined(OPENSSL) && OPENSSL_VERSION_NUMBER >= 0x0090700fL
 	EVP_MD_CTX_init(&ctx);
 #ifdef EVP_MD_CTX_FLAG_NON_FIPS_ALLOW
 	/* MD5 is not used as a crypto hash here. */
@@ -115,6 +125,10 @@ addr2refid(sockaddr_u *addr)
 		    "MD5 init failed");
 		exit(1);
 	}
+#else
+	EVP_DigestInit(&ctx, EVP_md5());
+#endif
+
 	EVP_DigestUpdate(&ctx, (u_char *)PSOCK_ADDR6(addr),
 	    sizeof(struct in6_addr));
 	EVP_DigestFinal(&ctx, digest, &len);
