@@ -5,6 +5,10 @@
 
 #include "unity.h"
 
+void test_RegularTime(void);
+void test_CurrentTime(void);
+
+
 void
 test_RegularTime(void)
 {
@@ -13,11 +17,13 @@ test_RegularTime(void)
 	struct tm* tm;
 
 	tm = localtime(&sample);
-	TEST_ASSERT_TRUE(time != NULL);
+	TEST_ASSERT_TRUE(tm != NULL);
 
 	snprintf(expected, 15, "%02d:%02d:%02d", tm->tm_hour, tm->tm_min, tm->tm_sec);
 
 	TEST_ASSERT_EQUAL_STRING(expected, humantime(sample));
+
+	return;
 }
 
 void
@@ -30,9 +36,11 @@ test_CurrentTime(void)
 	time(&sample);
 
 	tm = localtime(&sample);
-	TEST_ASSERT_TRUE(time != NULL);
+	TEST_ASSERT_TRUE(tm != NULL);
 
 	snprintf(expected, 15, "%02d:%02d:%02d", tm->tm_hour, tm->tm_min, tm->tm_sec);
 
 	TEST_ASSERT_EQUAL_STRING(expected, humantime(sample));
+
+	return;
 }
