@@ -14,8 +14,9 @@ void test_ClassAAddress(void);
 void test_IPv6Address(void);
 
 
-
-void test_ClassBAddress(void) {
+void
+test_ClassBAddress(void)
+{
 	sockaddr_u input = CreateSockaddr4("172.16.2.1", NTP_PORT);
 	sockaddr_u expected = CreateSockaddr4("172.16.0.0", NTP_PORT);
 
@@ -23,9 +24,13 @@ void test_ClassBAddress(void) {
 
 	TEST_ASSERT_TRUE(actual != NULL);
 	TEST_ASSERT_TRUE(IsEqual(expected, *actual));
+
+	return;
 }
 
-void test_ClassCAddress(void) {
+void
+test_ClassCAddress(void)
+{
 	sockaddr_u input = CreateSockaddr4("192.0.2.255", NTP_PORT);
 	sockaddr_u expected = CreateSockaddr4("192.0.2.0", NTP_PORT);
 
@@ -33,9 +38,14 @@ void test_ClassCAddress(void) {
 
 	TEST_ASSERT_TRUE(actual != NULL);
 	TEST_ASSERT_TRUE(IsEqual(expected, *actual));
+
+	return;
 }
 
-void  test_ClassAAddress(void) {
+
+void
+test_ClassAAddress(void)
+{
 	/* Class A addresses are assumed to be classless,
 	 * thus the same address should be returned.
 	 */
@@ -46,9 +56,13 @@ void  test_ClassAAddress(void) {
 
 	TEST_ASSERT_TRUE(actual != NULL);
 	TEST_ASSERT_TRUE(IsEqual(expected, *actual));
+
+	return;
 }
 
-void  test_IPv6Address(void) {
+void
+test_IPv6Address(void)
+{
 	/* IPv6 addresses are assumed to have 64-bit host- and 64-bit network parts. */
 	const struct in6_addr input_address = { { {
 		0x20, 0x01, 0x0d, 0xb8,
@@ -63,7 +77,7 @@ void  test_IPv6Address(void) {
 		0x00, 0x00, 0x00, 0x00,
 		0x00, 0x00, 0x00, 0x00
 	} } }; // 2001:0db8:85a3:08d3:0000:0000:0000:0000
-	
+
 	sockaddr_u input;
 	input.sa6.sin6_family = AF_INET6;
 	input.sa6.sin6_addr = input_address;
@@ -78,5 +92,6 @@ void  test_IPv6Address(void) {
 
 	TEST_ASSERT_TRUE(actual != NULL);
 	TEST_ASSERT_TRUE(IsEqual(expected, *actual));
-}
 
+	return;
+}
