@@ -9,6 +9,10 @@
 /* Might need to be updated if a new refclock gets this id. */
 static const int UNUSED_REFCLOCK_ID = 250;
 
+void test_LocalClock(void);
+void test_UnknownId(void);
+
+
 void
 test_LocalClock(void) {
 #ifdef REFCLOCK		/* clockname() is useless otherwise */
@@ -22,7 +26,7 @@ test_LocalClock(void) {
 	sockaddr_u address;
 	address.sa4.sin_family = AF_INET;
 	address.sa4.sin_addr.s_addr = htonl(addr);
-	
+
 	char stringStart[100]= "";
 
 	strcat(stringStart, clockname(REFCLK_LOCALCLOCK));
@@ -31,7 +35,7 @@ test_LocalClock(void) {
 	char * expected = stringStart;
 
 	TEST_ASSERT_EQUAL_STRING(expected, refnumtoa(&address));
-#else	
+#else
 	TEST_IGNORE_MESSAGE("REFCLOCK NOT DEFINED, SKIPPING TEST");
 #endif	/* REFCLOCK */
 }
@@ -47,16 +51,16 @@ test_UnknownId(void) {
 	sockaddr_u address;
 	address.sa4.sin_family = AF_INET;
 	address.sa4.sin_addr.s_addr = htonl(addr);
-	
+
 	char stringStart[100]= "REFCLK(";
-	char value[100] ;	
+	char value[100] ;
 	snprintf(value, sizeof(value), "%d", UNUSED_REFCLOCK_ID);
 	strcat(stringStart,value);
 	strcat(stringStart,",4)");
 	char * expected = stringStart;
 
 	TEST_ASSERT_EQUAL_STRING(expected, refnumtoa(&address));
-#else 	
+#else
 	TEST_IGNORE_MESSAGE("REFCLOCK NOT DEFINED, SKIPPING TEST");
 #endif	/* REFCLOCK */
 }
