@@ -2,64 +2,114 @@
 
 #include "ntp_types.h"
 #include "ntp_fp.h"
-
-#include <math.h>
 #include "timespecops.h"
 
 #include "unity.h"
 
-
+#include <math.h>
 #include <string.h>
 
-//in unity_helper.h :
-#define TEST_ASSERT_EQUAL_timespec(a, b) { \
-    TEST_ASSERT_EQUAL_MESSAGE(a.tv_sec, b.tv_sec, "Field tv_sec"); \
+
+#define TEST_ASSERT_EQUAL_timespec(a, b) {				\
+    TEST_ASSERT_EQUAL_MESSAGE(a.tv_sec, b.tv_sec, "Field tv_sec");	\
     TEST_ASSERT_EQUAL_MESSAGE(a.tv_nsec, b.tv_nsec, "Field tv_nsec");	\
 }
 
-//what about l_fp.l_ui  ??? it's a union so it's either l_fp.l_ui or l_fp.l_i?
-#define TEST_ASSERT_EQUAL_l_fp(a, b) { \
-    TEST_ASSERT_EQUAL_MESSAGE(a.l_i, b.l_i, "Field l_i"); \
+
+#define TEST_ASSERT_EQUAL_l_fp(a, b) {					\
+    TEST_ASSERT_EQUAL_MESSAGE(a.l_i, b.l_i, "Field l_i");		\
     TEST_ASSERT_EQUAL_UINT_MESSAGE(a.l_uf, b.l_uf, "Field l_uf");	\
 }
 
-//timespec has time_t, long, and time_t is basically long uint, 4 or 8 bytes size, depending on 32/64bit
 
 static u_int32 my_tick_to_tsf(u_int32 ticks);
 static u_int32 my_tsf_to_tick(u_int32 tsf);
 
+
 // that's it...
 struct lfpfracdata {
 	long	nsec;
 	u_int32 frac;
 };
 
-//******************************************MY CUSTOM FUNCTIONS*******************************
 
-typedef int bool; //TRUE and FALSE are already defined somewhere, so I can't do typedef enum { FALSE, TRUE } boolean;
+void test_Helpers1(void);
+void test_Normalise(void);
+void test_SignNoFrac(void);
+void test_SignWithFrac(void);
+void test_CmpFracEQ(void);
+void test_CmpFracGT(void);
+void test_CmpFracLT(void);
+void test_AddFullNorm(void);
+void test_AddFullOflow1(void);
+void test_AddNsecNorm(void);
+void test_AddNsecOflow1(void);
+void test_SubFullNorm(void);
+void test_SubFullOflow(void);
+void test_SubNsecNorm(void);
+void test_SubNsecOflow(void);
+void test_Neg(void);
+void test_AbsNoFrac(void);
+void test_AbsWithFrac(void);
+void test_Helpers2(void);
+void test_ToLFPbittest(void);
+void test_ToLFPrelPos(void);
+void test_ToLFPrelNeg(void);
+void test_ToLFPabs(void);
+void test_FromLFPbittest(void);
+void test_FromLFPrelPos(void);
+void test_FromLFPrelNeg(void);
+void test_LFProundtrip(void);
+void test_ToString(void);
 
-const bool timespec_isValid(struct timespec V)
-		{ return V.tv_nsec >= 0 && V.tv_nsec < 1000000000; }
+typedef int bool;
+
+const bool	timespec_isValid(struct timespec V);
+struct timespec timespec_init(time_t hi, long lo);
+l_fp		l_fp_init(int32 i, u_int32 f);
+bool		AssertFpClose(const l_fp m, const l_fp n, const l_fp limit);
+bool		AssertTimespecClose(const struct timespec m,
+				    const struct timespec n,
+				    const struct timespec limit);
+
+
+//***************************MY CUSTOM FUNCTIONS***************************
+
+
+const bool
+timespec_isValid(struct timespec V)
+{
+
+	return V.tv_nsec >= 0 && V.tv_nsec < 1000000000;
+}
+
+
+struct timespec
+timespec_init(time_t hi, long lo)
+{
+	struct timespec V;
 
-struct timespec timespec_init(time_t hi, long lo){
-	struct timespec V;	
 	V.tv_sec = hi;
 	V.tv_nsec = lo;
+
 	return V;
 }
 
-//taken from lfpfunc.c -> maybe remove this from timevalops.c and lfpfunc. and put in c_timstructs.h ????!!!!!
-l_fp l_fp_init(int32 i, u_int32 f)
+
+l_fp
+l_fp_init(int32 i, u_int32 f)
 {
 	l_fp temp;
+
 	temp.l_i  = i;
 	temp.l_uf = f;
 
 	return temp;
 }
 
-//also in timelalops.c!!!!!!
-bool AssertFpClose(const l_fp m,const l_fp n, const l_fp limit)
+
+bool
+AssertFpClose(const l_fp m, const l_fp n, const l_fp limit)
 {
 	l_fp diff;
 
@@ -70,17 +120,19 @@ bool AssertFpClose(const l_fp m,const l_fp n, const l_fp limit)
 		diff = n;
 		L_SUB(&diff, &m);
 	}
-	if (L_ISGEQ(&limit, &diff)){
+	if (L_ISGEQ(&limit, &diff)) {
 		return TRUE;
 	}
 	else {
-		printf("m_expr which is %s \nand\nn_expr which is %s\nare not close; diff=%susec\n",lfptoa(&m,10),lfptoa(&n,10),lfptoa(&diff,10)); 
+		printf("m_expr which is %s \nand\nn_expr which is %s\nare not close; diff=%susec\n", lfptoa(&m, 10), lfptoa(&n, 10), lfptoa(&diff, 10)); 
 		return FALSE;
 	}
 }
 
 
-bool AssertTimespecClose(const struct timespec m,const struct timespec n, const struct timespec limit)
+bool
+AssertTimespecClose(const struct timespec m, const struct timespec n,
+	const struct timespec limit)
 {
 	struct timespec diff;
 
@@ -89,7 +141,7 @@ bool AssertTimespecClose(const struct timespec m,const struct timespec n, const
 		return TRUE;
 	else
 	{
-		printf("m_expr which is %ld.%lu \nand\nn_expr which is %ld.%lu\nare not close; diff=%ld.%lunsec\n",m.tv_sec,m.tv_nsec,n.tv_sec,n.tv_nsec,diff.tv_sec,diff.tv_nsec); 
+		printf("m_expr which is %ld.%lu \nand\nn_expr which is %ld.%lu\nare not close; diff=%ld.%lunsec\n", m.tv_sec, m.tv_nsec, n.tv_sec, n.tv_nsec, diff.tv_sec, diff.tv_nsec); 
 		return FALSE;
 	}
 }
@@ -114,12 +166,14 @@ static const struct lfpfracdata fdata[] = {
 	};
 
 
-u_int32 my_tick_to_tsf(u_int32 ticks)
+u_int32
+my_tick_to_tsf(u_int32 ticks)
 {
 	// convert nanoseconds to l_fp fractional units, using double
 	// precision float calculations or, if available, 64bit integer
 	// arithmetic. This should give the precise fraction, rounded to
 	// the nearest representation.
+
 #ifdef HAVE_U_INT64
 	return (u_int32)((( ((u_int64)(ticks)) << 32) + 500000000) / 1000000000);
 #else
@@ -129,8 +183,11 @@ u_int32 my_tick_to_tsf(u_int32 ticks)
 	// truncated nonsense, so don't use it out-of-bounds.
 }
 
-u_int32 my_tsf_to_tick(u_int32 tsf)
+
+u_int32
+my_tsf_to_tick(u_int32 tsf)
 {
+
 	// Inverse operation: converts fraction to microseconds.
 #ifdef HAVE_U_INT64
 	return (u_int32)(( ((u_int64)(tsf)) * 1000000000 + 0x80000000) >> 32);
@@ -146,7 +203,9 @@ u_int32 my_tsf_to_tick(u_int32 tsf)
 // test support stuff -- part 1
 // ---------------------------------------------------------------------
 
-void test_Helpers1(void) {
+void
+test_Helpers1(void)
+{
 	struct timespec x;
 
 	for (x.tv_sec = -2; x.tv_sec < 3; x.tv_sec++) {
@@ -159,6 +218,8 @@ void test_Helpers1(void) {
 		x.tv_nsec = 1000000000;
 		TEST_ASSERT_FALSE(timespec_isValid(x));
 	}
+
+	return;
 }
 
 
@@ -166,23 +227,31 @@ void test_Helpers1(void) {
 // test normalisation
 //----------------------------------------------------------------------
 
-void test_Normalise(void) {
+void
+test_Normalise(void)
+{
 	long ns;
+
 	for ( ns = -2000000000; ns <= 2000000000; ns += 10000000) {
 		struct timespec x = timespec_init(0, ns);
 
 		x = normalize_tspec(x);
 		TEST_ASSERT_TRUE(timespec_isValid(x));
 	}
+
+	return;
 }
 
 //----------------------------------------------------------------------
 // test classification
 //----------------------------------------------------------------------
 
-void test_SignNoFrac(void) {
+void
+test_SignNoFrac(void)
+{
 	// sign test, no fraction
 	int i;
+
 	for (i = -4; i <= 4; ++i) {
 		struct timespec a = timespec_init(i, 0);
 		int E = (i > 0) - (i < 0);
@@ -190,67 +259,98 @@ void test_SignNoFrac(void) {
 
 		TEST_ASSERT_EQUAL(E, r);
 	}
+
+	return;
 }
 
-void test_SignWithFrac(void) {
+
+void
+test_SignWithFrac(void)
+{
 	// sign test, with fraction
 	int i;
+
 	for (i = -4; i <= 4; ++i) {
 		struct timespec a = timespec_init(i, 10);
 		int E = (i >= 0) - (i < 0);
 		int r = test_tspec(a);
+
 		TEST_ASSERT_EQUAL(E, r);
 	}
+
+	return;
 }
 
 //----------------------------------------------------------------------
 // test compare
 //----------------------------------------------------------------------
-void test_CmpFracEQ(void) {
+void
+test_CmpFracEQ(void)
+{
 	// fractions are equal
-	int i,j;
+	int i, j;
 	for (i = -4; i <= 4; ++i)
 		for (j = -4; j <= 4; ++j) {
 			struct timespec a = timespec_init( i , 200);
 			struct timespec b = timespec_init( j , 200);
 			int   E = (i > j) - (i < j);
 			int   r = cmp_tspec_denorm(a, b);
+
 			TEST_ASSERT_EQUAL(E, r);
 		}
+
+	return;
 }
 
-void test_CmpFracGT(void) {
+
+void
+test_CmpFracGT(void)
+{
 	// fraction a bigger fraction b
-	int i,j;
+	int i, j;
+
 	for (i = -4; i <= 4; ++i)
 		for (j = -4; j <= 4; ++j) {
 			struct timespec a = timespec_init(i, 999999800);
 			struct timespec b = timespec_init(j, 200);
 			int   E = (i >= j) - (i < j);
 			int   r = cmp_tspec_denorm(a, b);
+
 			TEST_ASSERT_EQUAL(E, r);
 		}
+
+	return;
 }
 
-void test_CmpFracLT(void) {
+
+void
+test_CmpFracLT(void)
+{
 	// fraction a less fraction b
-	int i,j;
+	int i, j;
+
 	for (i = -4; i <= 4; ++i)
 		for (j = -4; j <= 4; ++j) {
 			struct timespec a = timespec_init(i, 200);
 			struct timespec b = timespec_init(j, 999999800);
 			int   E = (i > j) - (i <= j);
 			int   r = cmp_tspec_denorm(a, b);
+
 			TEST_ASSERT_EQUAL(E, r);
 		}
+
+	return;
 }
 
 //----------------------------------------------------------------------
 // Test addition (sum)
 //----------------------------------------------------------------------
 
-void test_AddFullNorm(void) {
-	int i,j;
+void
+test_AddFullNorm(void)
+{
+	int i, j;
+
 	for (i = -4; i <= 4; ++i)
 		for (j = -4; j <= 4; ++j) {
 			struct timespec a = timespec_init(i, 200);
@@ -261,10 +361,16 @@ void test_AddFullNorm(void) {
 			c = add_tspec(a, b);
 			TEST_ASSERT_EQUAL_timespec(E, c);
 		}
+
+	return;
 }
 
-void test_AddFullOflow1(void) {
-	int i,j;
+
+void
+test_AddFullOflow1(void)
+{
+	int i, j;
+
 	for (i = -4; i <= 4; ++i)
 		for (j = -4; j <= 4; ++j) {
 			struct timespec a = timespec_init(i, 200);
@@ -275,10 +381,15 @@ void test_AddFullOflow1(void) {
 			c = add_tspec(a, b);
 			TEST_ASSERT_EQUAL_timespec(E, c);
 		}
+
+	return;
 }
 
-void test_AddNsecNorm(void) {
+
+void
+test_AddNsecNorm(void) {
 	int i;
+
 	for (i = -4; i <= 4; ++i) {
 		struct timespec a = timespec_init(i, 200);
 		struct timespec E = timespec_init(i, 600);
@@ -287,10 +398,16 @@ void test_AddNsecNorm(void) {
 		c = add_tspec_ns(a, 600 - 200);
 		TEST_ASSERT_EQUAL_timespec(E, c);
 	}
+
+	return;
 }
 
-void test_AddNsecOflow1(void) {
+
+void
+test_AddNsecOflow1(void)
+{
 	int i;
+
 	for (i = -4; i <= 4; ++i) {
 		struct timespec a = timespec_init(i, 200);
 		struct timespec E = timespec_init(i + 1, 100);
@@ -299,14 +416,19 @@ void test_AddNsecOflow1(void) {
 		c = add_tspec_ns(a, NANOSECONDS - 100);
 		TEST_ASSERT_EQUAL_timespec(E, c);
 	}
+
+	return;
 }
 
 //----------------------------------------------------------------------
 // test subtraction (difference)
 //----------------------------------------------------------------------
 
-void test_SubFullNorm(void) {
-	int i,j;
+void
+test_SubFullNorm(void)
+{
+	int i, j;
+
 	for (i = -4; i <= 4; ++i)
 		for (j = -4; j <= 4; ++j) {
 			struct timespec a = timespec_init( i , 600);
@@ -317,24 +439,36 @@ void test_SubFullNorm(void) {
 			c = sub_tspec(a, b);
 			TEST_ASSERT_EQUAL_timespec(E, c);
 		}
+
+	return;
 }
 
-void test_SubFullOflow(void) {
-	int i,j;
+
+void
+test_SubFullOflow(void)
+{
+	int i, j;
+
 	for (i = -4; i <= 4; ++i)
 		for (j = -4; j <= 4; ++j) {
-			struct timespec a = timespec_init(  i  , 100);
-			struct timespec b = timespec_init(  j  , 999999900);
-			struct timespec E = timespec_init(i-j-1, 200);
+			struct timespec a = timespec_init(i, 100);
+			struct timespec b = timespec_init(j, 999999900);
+			struct timespec E = timespec_init(i - j - 1, 200);
 			struct timespec c;
 
 			c = sub_tspec(a, b);
 			TEST_ASSERT_EQUAL_timespec(E, c);
 		}
+
+	return;
 }
 
-void test_SubNsecNorm(void) {
+
+void
+test_SubNsecNorm(void)
+{
 	int i;
+
 	for (i = -4; i <= 4; ++i) {
 		struct timespec a = timespec_init(i, 600);
 		struct timespec E = timespec_init(i, 200);
@@ -343,10 +477,16 @@ void test_SubNsecNorm(void) {
 		c = sub_tspec_ns(a, 600 - 200);
 		TEST_ASSERT_EQUAL_timespec(E, c);
 	}
+
+	return;
 }
 
-void test_SubNsecOflow(void) {
+
+void
+test_SubNsecOflow(void)
+{
 	int i;
+
 	for (i = -4; i <= 4; ++i) {
 		struct timespec a = timespec_init( i , 100);
 		struct timespec E = timespec_init(i-1, 200);
@@ -355,14 +495,20 @@ void test_SubNsecOflow(void) {
 		c = sub_tspec_ns(a, NANOSECONDS - 100);
 		TEST_ASSERT_EQUAL_timespec(E, c);
 	}
+
+	return;
 }
 
 //----------------------------------------------------------------------
 // test negation
 //----------------------------------------------------------------------
 
-void test_Neg(void) {
+
+void
+test_Neg(void)
+{
 	int i;
+
 	for (i = -4; i <= 4; ++i) {
 		struct timespec a = timespec_init(i, 100);
 		struct timespec b;
@@ -372,14 +518,19 @@ void test_Neg(void) {
 		c = add_tspec(a, b);
 		TEST_ASSERT_EQUAL(0, test_tspec(c));
 	}
+
+	return;
 }
 
 //----------------------------------------------------------------------
 // test abs value
 //----------------------------------------------------------------------
 
-void test_AbsNoFrac(void) {
+void
+test_AbsNoFrac(void)
+{
 	int i;
+
 	for (i = -4; i <= 4; ++i) {
 		struct timespec a = timespec_init(i , 0);
 		struct timespec b;
@@ -387,10 +538,16 @@ void test_AbsNoFrac(void) {
 		b = abs_tspec(a);
 		TEST_ASSERT_EQUAL((i != 0), test_tspec(b));
 	}
+
+	return;
 }
 
-void test_AbsWithFrac(void) {
+
+void
+test_AbsWithFrac(void)
+{
 	int i;
+
 	for (i = -4; i <= 4; ++i) {
 		struct timespec a = timespec_init(i, 100);
 		struct timespec b;
@@ -398,15 +555,18 @@ void test_AbsWithFrac(void) {
 		b = abs_tspec(a);
 		TEST_ASSERT_EQUAL(1, test_tspec(b));
 	}
+
+	return;
 }
 
 // ---------------------------------------------------------------------
 // test support stuff -- part 2
 // ---------------------------------------------------------------------
 
-void test_Helpers2(void) {
-	struct timespec limit = timespec_init(0,2);
-	
+void
+test_Helpers2(void)
+{
+	struct timespec limit = timespec_init(0, 2);
 	struct timespec x, y;
 	long i;
 
@@ -414,44 +574,51 @@ void test_Helpers2(void) {
 		for (x.tv_nsec = 1;
 		     x.tv_nsec < 1000000000;
 		     x.tv_nsec += 499999999) {
-			for (i = -4; i < 5; i++) {
+			for (i = -4; i < 5; ++i) {
 				y = x;
 				y.tv_nsec += i;
-				if (i >= -2 && i <= 2){
-					TEST_ASSERT_TRUE(AssertTimespecClose(x,y,limit));//ASSERT_PRED_FORMAT2(isClose, x, y);
+				if (i >= -2 && i <= 2) {
+					TEST_ASSERT_TRUE(AssertTimespecClose(x, y, limit));
 				}
 				else
 				{
-					TEST_ASSERT_FALSE(AssertTimespecClose(x,y,limit));
+					TEST_ASSERT_FALSE(AssertTimespecClose(x, y, limit));
 				}
 			}
 		}
-}
 
-// global predicate instances we're using here
-//static l_fp lfpClose =  l_fp_init(0,1); //static AssertFpClose FpClose(0, 1);
-//static struct timespec limit = timespec_init(0,2); //static AssertTimespecClose TimespecClose(0, 2);
+	return;
+}
 
 //----------------------------------------------------------------------
 // conversion to l_fp
 //----------------------------------------------------------------------
 
-void test_ToLFPbittest(void) {
-	l_fp lfpClose =  l_fp_init(0,1);
+void
+test_ToLFPbittest(void)
+{
+	l_fp lfpClose =  l_fp_init(0, 1);
 	u_int32 i;
+
 	for (i = 0; i < 1000000000; i+=1000) {
 		struct timespec a = timespec_init(1, i);
 		l_fp E= l_fp_init(1, my_tick_to_tsf(i));
 		l_fp r;
 
 		r = tspec_intv_to_lfp(a);
-		TEST_ASSERT_TRUE(AssertFpClose(E,r,lfpClose));
+		TEST_ASSERT_TRUE(AssertFpClose(E, r, lfpClose));
 	}
+
+	return;
 }
 
-void test_ToLFPrelPos(void) {
+
+void
+test_ToLFPrelPos(void)
+{
 	int i;
-	for (i = 0; i < COUNTOF(fdata); i++) {
+
+	for (i = 0; i < COUNTOF(fdata); ++i) {
 		struct timespec a = timespec_init(1, fdata[i].nsec);
 		l_fp E = l_fp_init(1, fdata[i].frac);
 		l_fp r;
@@ -459,11 +626,17 @@ void test_ToLFPrelPos(void) {
 		r = tspec_intv_to_lfp(a);
 		TEST_ASSERT_EQUAL_l_fp(E, r);
 	}
+
+	return;
 }
 
-void test_ToLFPrelNeg(void) {
+
+void
+test_ToLFPrelNeg(void)
+{
 	int i;
-	for (i = 0; i < COUNTOF(fdata); i++) {
+
+	for (i = 0; i < COUNTOF(fdata); ++i) {
 		struct timespec a = timespec_init(-1, fdata[i].nsec);
 		l_fp E = l_fp_init(~0, fdata[i].frac);
 		l_fp r;
@@ -471,11 +644,17 @@ void test_ToLFPrelNeg(void) {
 		r = tspec_intv_to_lfp(a);
 		TEST_ASSERT_EQUAL_l_fp(E, r);
 	}
+
+	return;
 }
 
-void test_ToLFPabs(void) {
+
+void
+test_ToLFPabs(void)
+{
 	int i;
-	for (i = 0; i < COUNTOF(fdata); i++) {
+
+	for (i = 0; i < COUNTOF(fdata); ++i) {
 		struct timespec a = timespec_init(1, fdata[i].nsec);
 		l_fp E = l_fp_init(1 + JAN_1970, fdata[i].frac);
 		l_fp r;
@@ -483,13 +662,18 @@ void test_ToLFPabs(void) {
 		r = tspec_stamp_to_lfp(a);
 		TEST_ASSERT_EQUAL_l_fp(E, r);
 	}
+
+	return;
 }
 
 //----------------------------------------------------------------------
 // conversion from l_fp
 //----------------------------------------------------------------------
-void test_FromLFPbittest(void) {
-	struct timespec limit = timespec_init(0,2);
+
+void
+test_FromLFPbittest(void)
+{
+	struct timespec limit = timespec_init(0, 2);
 
 	// Not *exactly* a bittest, because 2**32 tests would take a
 	// really long time even on very fast machines! So we do test
@@ -503,43 +687,60 @@ void test_FromLFPbittest(void) {
 		r = lfp_intv_to_tspec(a);
 		// The conversion might be off by one nanosecond when
 		// comparing to calculated value.
-		TEST_ASSERT_TRUE(AssertTimespecClose(E,r,limit));
+		TEST_ASSERT_TRUE(AssertTimespecClose(E, r, limit));
 	}
+
+	return;
 }
 
-void test_FromLFPrelPos(void) {
-	struct timespec limit = timespec_init(0,2);
+
+void
+test_FromLFPrelPos(void)
+{
+	struct timespec limit = timespec_init(0, 2);
 	int i;
-	for (i = 0; i < COUNTOF(fdata); i++) {
+
+	for (i = 0; i < COUNTOF(fdata); ++i) {
 		l_fp a = l_fp_init(1, fdata[i].frac);
 		struct timespec E = timespec_init(1, fdata[i].nsec);
 		struct timespec r;
 
 		r = lfp_intv_to_tspec(a);
-		TEST_ASSERT_TRUE(AssertTimespecClose(E,r,limit));
+		TEST_ASSERT_TRUE(AssertTimespecClose(E, r, limit));
 	}
+
+	return;
 }
 
-void test_FromLFPrelNeg(void) {
-	struct timespec limit = timespec_init(0,2);
+
+void
+test_FromLFPrelNeg(void)
+{
+	struct timespec limit = timespec_init(0, 2);
 	int i;
-	for (i = 0; i < COUNTOF(fdata); i++) {
+
+	for (i = 0; i < COUNTOF(fdata); ++i) {
 		l_fp a = l_fp_init(~0, fdata[i].frac);
 		struct timespec E = timespec_init(-1, fdata[i].nsec);
 		struct timespec r;
 
 		r = lfp_intv_to_tspec(a);
-		TEST_ASSERT_TRUE(AssertTimespecClose(E,r,limit));
+		TEST_ASSERT_TRUE(AssertTimespecClose(E, r, limit));
 	}
+
+	return;
 }
 
 
 // nsec -> frac -> nsec roundtrip, using a prime start and increment
-void test_LFProundtrip(void) {
+void
+test_LFProundtrip(void)
+{
 	int32_t t;
 	u_int32 i;
+
 	for (t = -1; t < 2; ++t)
-		for (i = 4999; i < 1000000000; i+=10007) {
+		for (i = 4999; i < 1000000000; i += 10007) {
 			struct timespec E = timespec_init(t, i);
 			l_fp a;
 			struct timespec r;
@@ -548,13 +749,17 @@ void test_LFProundtrip(void) {
 			r = lfp_intv_to_tspec(a);
 			TEST_ASSERT_EQUAL_timespec(E, r);
 		}
+
+	return;
 }
 
 //----------------------------------------------------------------------
 // string formatting
 //----------------------------------------------------------------------
 
-void test_ToString(void) {
+void
+test_ToString(void)
+{
 	static const struct {
 		time_t		sec;
 		long		nsec;
@@ -570,12 +775,15 @@ void test_ToString(void) {
 		{-1,-1, "-1.000000001" },
 	};
 	int i;
-	for (i = 0; i < COUNTOF(data); i++) {
+
+	for (i = 0; i < COUNTOF(data); ++i) {
 		struct timespec a = timespec_init(data[i].sec, data[i].nsec);
 		const char * E = data[i].repr;
 		const char * r = tspectoa(a);
 		TEST_ASSERT_EQUAL_STRING(E, r);
 	}
+
+	return;
 }
 
 // -*- EOF -*-
